@@ -16,13 +16,13 @@
 %                                April 2004                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2004 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -41,10 +41,13 @@
 #include "magick/studio.h"
 #include "magick/attribute.h"
 #include "magick/blob.h"
+#include "magick/blob-private.h"
 #include "magick/colorspace.h"
 #include "magick/constitute.h"
-#include "magick/error.h"
+#include "magick/exception.h"
+#include "magick/exception-private.h"
 #include "magick/image.h"
+#include "magick/image-private.h"
 #include "magick/list.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
@@ -178,12 +181,12 @@ static MagickBooleanType WriteCIPImage(const ImageInfo *image_info,Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
   (void) WriteBlobString(image,"<CiscoIPPhoneImage>\n");
-  attribute=GetImageAttribute(image,"label");
+  attribute=GetImageAttribute(image,"Label");
   if (attribute != (const ImageAttribute *) NULL)
     (void) FormatMagickString(buffer,MaxTextExtent,"<Title>%s</Title>\n",
       attribute->value);
@@ -221,10 +224,10 @@ static MagickBooleanType WriteCIPImage(const ImageInfo *image_info,Image *image)
     for (x=0; x < ((long) image->columns-3); x+=4)
     {
       byte=(unsigned char)
-        (((4*PixelIntensityToQuantum(p+3)/MaxRGB) & 0x03) << 6) |
-			   (((4*PixelIntensityToQuantum(p+2)/MaxRGB) & 0x03) << 4) |
-			   (((4*PixelIntensityToQuantum(p+1)/MaxRGB) & 0x03) << 2) |
-			   (((4*PixelIntensityToQuantum(p+0)/MaxRGB) & 0x03) << 0);
+        (((4*PixelIntensityToQuantum(p+3)/QuantumRange) & 0x03) << 6) |
+         (((4*PixelIntensityToQuantum(p+2)/QuantumRange) & 0x03) << 4) |
+         (((4*PixelIntensityToQuantum(p+1)/QuantumRange) & 0x03) << 2) |
+         (((4*PixelIntensityToQuantum(p+0)/QuantumRange) & 0x03) << 0);
       (void) FormatMagickString(buffer,MaxTextExtent,"%02x",byte);
       (void) WriteBlobString(image,buffer);
       p+=4;
@@ -233,16 +236,18 @@ static MagickBooleanType WriteCIPImage(const ImageInfo *image_info,Image *image)
       {
         i=(long) image->columns % 4;
         byte=(unsigned char)
-          ((((4*PixelIntensityToQuantum(p+Min(i,3))/MaxRGB) & 0x03) << 6) |
-  			   (((4*PixelIntensityToQuantum(p+Min(i,2))/MaxRGB) & 0x03) << 4) |
-  			   (((4*PixelIntensityToQuantum(p+Min(i,1))/MaxRGB) & 0x03) << 2) |
-  			   (((4*PixelIntensityToQuantum(p+Min(i,0))/MaxRGB) & 0x03) << 0));
+          ((((4*PixelIntensityToQuantum(p+Min(i,3))/QuantumRange) & 0x03) << 6) |
+           (((4*PixelIntensityToQuantum(p+Min(i,2))/QuantumRange) & 0x03) << 4) |
+           (((4*PixelIntensityToQuantum(p+Min(i,1))/QuantumRange) & 0x03) << 2) |
+           (((4*PixelIntensityToQuantum(p+Min(i,0))/QuantumRange) & 0x03) << 0));
         (void) FormatMagickString(buffer,MaxTextExtent,"%02x",~byte);
         (void) WriteBlobString(image,buffer);
       }
-    if (QuantumTick(y,image->rows) != MagickFalse)
+    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+        (QuantumTick(y,image->rows) != MagickFalse))
       {
-        status=MagickMonitor(SaveImageTag,y,image->rows,&image->exception);
+        status=image->progress_monitor(SaveImageTag,y,image->rows,
+          image->client_data);
         if (status == MagickFalse)
           break;
       }
