@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -41,13 +41,13 @@
 */
 #include "magick/studio.h"
 #include "magick/blob.h"
-#include "magick/blob_private.h"
+#include "magick/blob-private.h"
 #include "magick/client.h"
 #include "magick/constitute.h"
 #include "magick/exception.h"
-#include "magick/exception_private.h"
+#include "magick/exception-private.h"
 #include "magick/image.h"
-#include "magick/image_private.h"
+#include "magick/image-private.h"
 #include "magick/list.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
@@ -56,13 +56,13 @@
 #include "magick/static.h"
 #include "magick/string_.h"
 #include "magick/utility.h"
-#include "magick/xwindow.h"
-#if defined(HasDOT)
+#include "magick/xwindow-private.h"
+#if defined(HasGVC)
 #undef HAVE_CONFIG_H
-#include <dotneato.h>
+#include <gvc.h>
 #endif
 
-#if defined(HasDOT)
+#if defined(HasGVC)
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -92,14 +92,14 @@
 */
 static Image *ReadDOTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
-  Agraph_t
-    *graph,
-    *previous_graph;
-
   char
     **argv,
     command[MaxTextExtent];
 
+  graph_t
+    *graph,
+    *previous_graph;
+
   GVC_t
     *gvc;
 
@@ -118,21 +118,14 @@ static Image *ReadDOTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   register long
     i;
 
-  static char
-    *dot_info[] =
-    {
-      "dot",
-      "1.12",
-      "Sun Apr 11 18:49:30 UTC 2004"
-    };
-
   /*
     Open image file.
   */
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -141,29 +134,28 @@ static Image *ReadDOTImage(const ImageInfo *image_info,ExceptionInfo *exception)
     return((Image *) NULL);
   CloseBlob(image);
   image=DestroyImage(image);
-  graph=(Agraph_t *) NULL;
-  previous_graph=(Agraph_t *) NULL;
+  graph=(graph_t *) NULL;
+  previous_graph=(graph_t *) NULL;
   read_info=CloneImageInfo(image_info);
   (void) CopyMagickString(read_info->magick,"PS",MaxTextExtent);
   (void) AcquireUniqueFilename(read_info->filename);
   (void) FormatMagickString(command,MaxTextExtent,"-Tps2 -o%s %s",
     read_info->filename,image_info->filename);
   argv=StringToArgv(command,&argc);
-  gvc=gvNEWcontext(dot_info,"dot");
-  dotneato_initialize(gvc,argc,argv);
-  while ((graph=next_input_graph()) != (Agraph_t *) NULL)
+  gvc=gvContext();
+  parse_args(gvc,argc,argv);
+  while ((graph=next_input_graph()) != (graph_t *) NULL)
   {
-    if (previous_graph != (Agraph_t *) NULL)
+    if (previous_graph != (graph_t *) NULL)
       {
-        dot_cleanup(previous_graph);
+        gvlayout_cleanup(gvc,previous_graph);
         agclose(previous_graph);
       }
+    gvlayout_layout(gvc,graph);
+    emit_jobs(gvc,graph);
     previous_graph=graph;
-    gvBindContext(gvc,graph);
-    dot_layout(graph);
-    dotneato_write(gvc);
   }
-  dotneato_eof(gvc);
+  gvCleanup(gvc);
   for (i=0; i < argc; i++)
     argv[i]=(char *) RelinquishMagickMemory(argv[i]);
   argv=(char **) RelinquishMagickMemory(argv);
@@ -208,7 +200,7 @@ ModuleExport void RegisterDOTImage(void)
     *entry;
 
   entry=SetMagickInfo("DOT");
-#if defined(HasDOT)
+#if defined(HasGVC)
   entry->decoder=(DecoderHandler *) ReadDOTImage;
 #endif
   entry->blob_support=MagickFalse;
