@@ -178,7 +178,7 @@ typedef struct _DPXOrientationInfo
     x_size,
     y_size;
 
-  unsigned char
+  char
     filename[100],
     timestamp[24],
     device[32],
@@ -222,11 +222,32 @@ typedef struct _DPXTelevisionInfo
     reserve[76];
 } DPXTelevisionInfo;
 
-typedef struct _DPXInfoInfo
+typedef struct _DPXUserInfo
 {
   char
     id[32];
 } DPXUserInfo;
+
+typedef struct DPXInfo
+{
+  DPXFileInfo
+    file;
+
+  DPXImageInfo
+    image;
+
+  DPXOrientationInfo
+    orientation;
+
+  DPXFilmInfo
+    film;
+
+  DPXTelevisionInfo
+    television;
+
+  DPXUserInfo
+    user;
+} DPXInfo;
 
 /*
   Forward declaractions.
@@ -307,23 +328,8 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   char
     magick[4];
 
-  DPXFileInfo
-    dpx_file;
-
-  DPXFilmInfo
-    dpx_film;
-
-  DPXImageInfo
-    dpx_image;
-
-  DPXOrientationInfo
-    dpx_orientation;
-
-  DPXTelevisionInfo
-    dpx_television;
-
-  DPXUserInfo
-    dpx_user;
+  DPXInfo
+    dpx;
 
   Image
     *image;
@@ -354,6 +360,7 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
   unsigned char
     colortype,
+    single[16],
     *pixels;
 
   /*
@@ -383,31 +390,51 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   image->endian=LSBEndian;
   if (LocaleNCompare(magick,"SDPX",4) == 0)
     image->endian=MSBEndian;
-  dpx_file.image_offset=ReadBlobLong(image);
-  (void) ReadBlob(image,8,(unsigned char *) dpx_file.version);
-  (void) SetImageAttribute(image,"dpx:file.version",dpx_file.version);
-  dpx_file.file_size=ReadBlobLong(image);
-  dpx_file.ditto_key=ReadBlobLong(image);
-  dpx_file.generic_size=ReadBlobLong(image);
-  dpx_file.industry_size=ReadBlobLong(image);
-  dpx_file.user_size=ReadBlobLong(image);
-  (void) ReadBlob(image,100,(unsigned char *) dpx_file.filename);
-  (void) SetImageAttribute(image,"dpx:file.filename",dpx_file.filename);
-  (void) ReadBlob(image,24,(unsigned char *) dpx_file.timestamp);
-  (void) SetImageAttribute(image,"dpx:file.timestamp",dpx_file.timestamp);
-  (void) ReadBlob(image,100,(unsigned char *) dpx_file.creator);
-  (void) SetImageAttribute(image,"dpx:file.creator",dpx_file.creator);
-  (void) ReadBlob(image,200,(unsigned char *) dpx_file.project);
-  (void) SetImageAttribute(image,"dpx:file.project",dpx_file.project);
-  (void) ReadBlob(image,200,(unsigned char *) dpx_file.copyright);
-  (void) SetImageAttribute(image,"dpx:file.copyright",dpx_file.copyright);
-  dpx_file.encrypt_key=ReadBlobLong(image);
-  (void) ReadBlob(image,104,(unsigned char *) dpx_file.reserve);
-  dpx_image.orientation=ReadBlobShort(image);
+  dpx.file.image_offset=ReadBlobLong(image);
+  (void) ReadBlob(image,8,(unsigned char *) dpx.file.version);
+  (void) SetImageAttribute(image,"dpx:file.version",dpx.file.version);
+  dpx.file.file_size=ReadBlobLong(image);
+  dpx.file.ditto_key=ReadBlobLong(image);
+  if (dpx.file.ditto_key != (unsigned long) (~0))
+    (void) FormatImageAttribute(image,"dpx:file.ditto.key","%lu",
+      dpx.file.ditto_key);
+  dpx.file.generic_size=ReadBlobLong(image);
+  dpx.file.industry_size=ReadBlobLong(image);
+  dpx.file.user_size=ReadBlobLong(image);
+  (void) ReadBlob(image,100,(unsigned char *) dpx.file.filename);
+  (void) SetImageAttribute(image,"dpx:file.filename",dpx.file.filename);
+  if (*dpx.file.filename != '\0')
+    (void) FormatImageAttribute(image,"dpx:file.filename","%.100s",
+      dpx.file.filename);
+  (void) ReadBlob(image,24,(unsigned char *) dpx.file.timestamp);
+  if (*dpx.file.timestamp != '\0')
+    (void) FormatImageAttribute(image,"dpx:file.tilestamp","%.24s",
+      dpx.file.timestamp);
+  (void) ReadBlob(image,100,(unsigned char *) dpx.file.creator);
+  if (*dpx.file.creator != '\0')
+    (void) FormatImageAttribute(image,"dpx:file.creator","%.100s",
+      dpx.file.creator);
+  (void) ReadBlob(image,200,(unsigned char *) dpx.file.project);
+  if (*dpx.file.project != '\0')
+    (void) FormatImageAttribute(image,"dpx:file.project","%.200s",
+      dpx.file.project);
+  (void) ReadBlob(image,200,(unsigned char *) dpx.file.copyright);
+  if (*dpx.file.copyright != '\0')
+    (void) FormatImageAttribute(image,"dpx:file.copyright","%.200s",
+      dpx.file.copyright);
+  dpx.file.encrypt_key=ReadBlobLong(image);
+  if (dpx.file.encrypt_key != (unsigned long) (~0))
+    (void) FormatImageAttribute(image,"dpx:file.encrypt_key","%lu",
+      dpx.file.encrypt_key);
+  (void) ReadBlob(image,104,(unsigned char *) dpx.file.reserve);
   /*
     Read DPX image header.
   */
-  switch (dpx_image.orientation)
+  dpx.image.orientation=ReadBlobShort(image);
+  if (dpx.image.orientation != (unsigned short) (~0))
+    (void) FormatImageAttribute(image,"dpx:image.orientation","%d",
+      dpx.image.orientation);
+  switch (dpx.image.orientation)
   {
     default:
     case 0:  image->orientation=TopLeftOrientation; break;
@@ -419,96 +446,144 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     case 6:  image->orientation=LeftBottomOrientation; break;
     case 7:  image->orientation=RightBottomOrientation; break;
   }
-  dpx_image.number_elements=ReadBlobShort(image);
-  dpx_image.pixels_per_line=ReadBlobLong(image);
-  image->columns=dpx_image.pixels_per_line;
-  dpx_image.lines_per_element=ReadBlobLong(image);
-  image->rows=dpx_image.lines_per_element;
+  dpx.image.number_elements=ReadBlobShort(image);
+  dpx.image.pixels_per_line=ReadBlobLong(image);
+  image->columns=dpx.image.pixels_per_line;
+  dpx.image.lines_per_element=ReadBlobLong(image);
+  image->rows=dpx.image.lines_per_element;
   for (i=0; i < 8; i++)
   {
-    dpx_image.image_element[i].data_sign=ReadBlobLong(image);
-    dpx_image.image_element[i].low_data=ReadBlobLong(image);
-    dpx_image.image_element[i].low_quantity=ReadBlobLong(image);
-    dpx_image.image_element[i].high_data=ReadBlobLong(image);
-    dpx_image.image_element[i].high_quantity=ReadBlobLong(image);
-    dpx_image.image_element[i].descriptor=ReadBlobByte(image);
-    dpx_image.image_element[i].transfer=ReadBlobByte(image);
-    dpx_image.image_element[i].colorimetric=ReadBlobByte(image);
-    dpx_image.image_element[i].bit_size=ReadBlobByte(image);
-    dpx_image.image_element[i].packing=ReadBlobShort(image);
-    dpx_image.image_element[i].encoding=ReadBlobShort(image);
-    dpx_image.image_element[i].data_offset=ReadBlobLong(image);
-    dpx_image.image_element[i].end_of_line_padding=ReadBlobLong(image);
-    dpx_image.image_element[i].end_of_image_padding=ReadBlobLong(image);
+    dpx.image.image_element[i].data_sign=ReadBlobLong(image);
+    dpx.image.image_element[i].low_data=ReadBlobLong(image);
+    (void) ReadBlob(image,4,single);
+    dpx.image.image_element[i].low_quantity=((float *) single)[0];
+    dpx.image.image_element[i].high_data=ReadBlobLong(image);
+    (void) ReadBlob(image,4,single);
+    dpx.image.image_element[i].high_quantity=((float *) single)[0];
+    dpx.image.image_element[i].descriptor=ReadBlobByte(image);
+    dpx.image.image_element[i].transfer=ReadBlobByte(image);
+    dpx.image.image_element[i].colorimetric=ReadBlobByte(image);
+    dpx.image.image_element[i].bit_size=ReadBlobByte(image);
+    dpx.image.image_element[i].packing=ReadBlobShort(image);
+    dpx.image.image_element[i].encoding=ReadBlobShort(image);
+    dpx.image.image_element[i].data_offset=ReadBlobLong(image);
+    dpx.image.image_element[i].end_of_line_padding=ReadBlobLong(image);
+    dpx.image.image_element[i].end_of_image_padding=ReadBlobLong(image);
     (void) ReadBlob(image,32,(unsigned char *)
-      dpx_image.image_element[i].description);
+      dpx.image.image_element[i].description);
   }
-  (void) ReadBlob(image,52,(unsigned char *) dpx_image.reserve);
-  colortype=dpx_image.image_element[0].descriptor;
-  image->depth=dpx_image.image_element[0].bit_size;
+  (void) ReadBlob(image,52,(unsigned char *) dpx.image.reserve);
+  colortype=dpx.image.image_element[0].descriptor;
+  image->depth=dpx.image.image_element[0].bit_size;
   /*
     Read DPX orientation header.
   */
-  dpx_orientation.x_offset=ReadBlobLong(image);
-  dpx_orientation.y_offset=ReadBlobLong(image);
-  dpx_orientation.x_center=ReadBlobLong(image);
-  dpx_orientation.y_center=ReadBlobLong(image);
-  dpx_orientation.x_size=ReadBlobLong(image);
-  dpx_orientation.y_size=ReadBlobLong(image);
-  (void) ReadBlob(image,100,(unsigned char *) dpx_orientation.filename);
-  (void) ReadBlob(image,24,(unsigned char *) dpx_orientation.timestamp);
-  (void) ReadBlob(image,32,(unsigned char *) dpx_orientation.device);
-  (void) ReadBlob(image,32,(unsigned char *) dpx_orientation.serial);
+  dpx.orientation.x_offset=ReadBlobLong(image);
+  dpx.orientation.y_offset=ReadBlobLong(image);
+  (void) ReadBlob(image,4,single);
+  dpx.orientation.x_center=((float *) single)[0];
+  (void) ReadBlob(image,4,single);
+  dpx.orientation.y_center=((float *) single)[0];
+  dpx.orientation.x_size=ReadBlobLong(image);
+  dpx.orientation.y_size=ReadBlobLong(image);
+  (void) ReadBlob(image,100,(unsigned char *) dpx.orientation.filename);
+  if (*dpx.orientation.filename != '\0')
+    (void) FormatImageAttribute(image,"dpx:orientation.copyright","%.100s",
+      dpx.orientation.filename);
+  (void) ReadBlob(image,24,(unsigned char *) dpx.orientation.timestamp);
+  if (*dpx.orientation.timestamp != '\0')
+    (void) FormatImageAttribute(image,"dpx:orientation.timestamp","%.24s",
+      dpx.orientation.timestamp);
+  (void) ReadBlob(image,32,(unsigned char *) dpx.orientation.device);
+  if (*dpx.orientation.device != '\0')
+    (void) FormatImageAttribute(image,"dpx:orientation.device","%.32s",
+      dpx.orientation.device);
+  (void) ReadBlob(image,32,(unsigned char *) dpx.orientation.serial);
+  if (*dpx.orientation.serial != '\0')
+    (void) FormatImageAttribute(image,"dpx:orientation.serial","%.32s",
+      dpx.orientation.serial);
   for (i=0; i < 4; i++)
-    dpx_orientation.border[i]=ReadBlobShort(image);
+    dpx.orientation.border[i]=ReadBlobShort(image);
   for (i=0; i < 2; i++)
-    dpx_orientation.aspect_ratio[i]=ReadBlobLong(image);
-  (void) ReadBlob(image,28,(unsigned char *) dpx_orientation.reserve);
+    dpx.orientation.aspect_ratio[i]=ReadBlobLong(image);
+  (void) ReadBlob(image,28,(unsigned char *) dpx.orientation.reserve);
   /*
     Read DPX film header.
   */
-  (void) ReadBlob(image,2,(unsigned char *) dpx_film.id);
-  (void) ReadBlob(image,2,(unsigned char *) dpx_film.type);
-  (void) ReadBlob(image,2,(unsigned char *) dpx_film.offset);
-  (void) ReadBlob(image,6,(unsigned char *) dpx_film.prefix);
-  (void) ReadBlob(image,4,(unsigned char *) dpx_film.count);
-  (void) ReadBlob(image,32,(unsigned char *) dpx_film.format);
-  dpx_film.frame_position=ReadBlobLong(image);
-  dpx_film.sequence_length=ReadBlobLong(image);
-  dpx_film.held_count=ReadBlobLong(image);
-  dpx_film.frame_rate=ReadBlobLong(image);
-  dpx_film.shutter_angle=ReadBlobLong(image);
-  (void) ReadBlob(image,32,(unsigned char *) dpx_film.frame_id);
-  (void) ReadBlob(image,100,(unsigned char *) dpx_film.slate);
-  (void) ReadBlob(image,56,(unsigned char *) dpx_film.reserve);
+  (void) ReadBlob(image,2,(unsigned char *) dpx.film.id);
+  if (*dpx.film.type != '\0')
+    (void) FormatImageAttribute(image,"dpx:film.id","%.2s",dpx.film.id);
+  (void) ReadBlob(image,2,(unsigned char *) dpx.film.type);
+  if (*dpx.film.type != '\0')
+    (void) FormatImageAttribute(image,"dpx:film.type","%.2s",dpx.film.type);
+  (void) ReadBlob(image,2,(unsigned char *) dpx.film.offset);
+  if (*dpx.film.offset != '\0')
+    (void) FormatImageAttribute(image,"dpx:film.offset","%.2s",dpx.film.offset);
+  (void) ReadBlob(image,6,(unsigned char *) dpx.film.prefix);
+  if (*dpx.film.prefix != '\0')
+    (void) FormatImageAttribute(image,"dpx:film.prefix","%.6s",dpx.film.prefix);
+  (void) ReadBlob(image,4,(unsigned char *) dpx.film.count);
+  if (*dpx.film.count != '\0')
+    (void) FormatImageAttribute(image,"dpx:film.count","%.4s",dpx.film.count);
+  (void) ReadBlob(image,32,(unsigned char *) dpx.film.format);
+  if (*dpx.film.format != '\0')
+    (void) FormatImageAttribute(image,"dpx:film.format","%.4s",dpx.film.format);
+  dpx.film.frame_position=ReadBlobLong(image);
+  dpx.film.sequence_length=ReadBlobLong(image);
+  dpx.film.held_count=ReadBlobLong(image);
+  (void) ReadBlob(image,4,single);
+  dpx.film.frame_rate=((float *) single)[0];
+  (void) ReadBlob(image,4,single);
+  dpx.film.shutter_angle=((float *) single)[0];
+  (void) ReadBlob(image,32,(unsigned char *) dpx.film.frame_id);
+  if (*dpx.film.frame_id != '\0')
+    (void) FormatImageAttribute(image,"dpx:film.frame_id","%.32s",
+      dpx.film.frame_id);
+  (void) ReadBlob(image,100,(unsigned char *) dpx.film.slate);
+  if (*dpx.film.slate != '\0')
+    (void) FormatImageAttribute(image,"dpx:film.slate","%.100s",
+      dpx.film.slate);
+  (void) ReadBlob(image,56,(unsigned char *) dpx.film.reserve);
   /*
     Read DPX televison header.
   */
-  dpx_television.time_code=ReadBlobLong(image);
-  dpx_television.user_bits=ReadBlobLong(image);
-  dpx_television.interlace=ReadBlobByte(image);
-  dpx_television.field_number=ReadBlobByte(image);
-  dpx_television.video_signal=ReadBlobByte(image);
-  dpx_television.padding=ReadBlobByte(image);
-  dpx_television.horizontal_sample_rate=ReadBlobLong(image);
-  dpx_television.vertical_sample_rate=ReadBlobLong(image);
-  dpx_television.frame_rate=ReadBlobLong(image);
-  dpx_television.time_offset=ReadBlobLong(image);
-  dpx_television.gamma=ReadBlobLong(image);
-  dpx_television.black_level=ReadBlobLong(image);
-  dpx_television.black_gain=ReadBlobLong(image);
-  dpx_television.break_point=ReadBlobLong(image);
-  dpx_television.white_level=ReadBlobLong(image);
-  dpx_television.integration_times=ReadBlobLong(image);
-  (void) ReadBlob(image,76,(unsigned char *) dpx_television.reserve);
+  dpx.television.time_code=ReadBlobLong(image);
+  dpx.television.user_bits=ReadBlobLong(image);
+  dpx.television.interlace=ReadBlobByte(image);
+  dpx.television.field_number=ReadBlobByte(image);
+  dpx.television.video_signal=ReadBlobByte(image);
+  dpx.television.padding=ReadBlobByte(image);
+  (void) ReadBlob(image,4,single);
+  dpx.television.horizontal_sample_rate=((float *) single)[0];
+  (void) ReadBlob(image,4,single);
+  dpx.television.vertical_sample_rate=((float *) single)[0];
+  (void) ReadBlob(image,4,single);
+  dpx.television.frame_rate=((float *) single)[0];
+  (void) ReadBlob(image,4,single);
+  dpx.television.time_offset=((float *) single)[0];
+  (void) ReadBlob(image,4,single);
+  dpx.television.gamma=((float *) single)[0];
+  (void) ReadBlob(image,4,single);
+  dpx.television.black_level=((float *) single)[0];
+  (void) ReadBlob(image,4,single);
+  dpx.television.black_gain=((float *) single)[0];
+  (void) ReadBlob(image,4,single);
+  dpx.television.break_point=((float *) single)[0];
+  (void) ReadBlob(image,4,single);
+  dpx.television.white_level=((float *) single)[0];
+  (void) ReadBlob(image,4,single);
+  dpx.television.integration_times=((float *) single)[0];
+  (void) ReadBlob(image,76,(unsigned char *) dpx.television.reserve);
   /*
     Read DPX user header.
   */
-  (void) ReadBlob(image,32,(unsigned char *) dpx_user.id);
+  (void) ReadBlob(image,32,(unsigned char *) dpx.user.id);
+  if (*dpx.user.id != '\0')
+    (void) FormatImageAttribute(image,"dpx:user.id","%.32s",dpx.user.id);
   /*
     Read DPX image header.
   */
-  for (i=0; i < (long) (dpx_file.image_offset-2080); i++)
+  for (i=0; i < (long) (dpx.file.image_offset-2080); i++)
     (void) ReadBlobByte(image);
   if (image_info->ping != MagickFalse)
     {
@@ -655,8 +730,8 @@ ModuleExport void UnregisterDPXImage(void)
 */
 static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
 {
-  DPXFileInfo
-    dpx_file;
+  DPXInfo
+    dpx;
 
   long
     y;
@@ -691,12 +766,12 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  (void) ResetMagickMemory(&dpx_file,0,sizeof(dpx_file));
+  (void) ResetMagickMemory(&dpx.file,0,sizeof(dpx.file));
   (void) SetImageColorspace(image,LogColorspace);
   (void) WriteBlobLong(image,0x53445058);
   (void) WriteBlobLong(image,0x2000);
-  (void) CopyMagickString(dpx_file.version,"V2.0",MaxTextExtent);
-  (void) WriteBlob(image,8,(unsigned char *) &dpx_file.version);
+  (void) CopyMagickString(dpx.file.version,"V2.0",MaxTextExtent);
+  (void) WriteBlob(image,8,(unsigned char *) &dpx.file.version);
   (void) WriteBlobLong(image,4*image->columns*image->rows+0x2000);
   (void) WriteBlobLong(image,0x00000001);
   (void) WriteBlobLong(image,0x00000680);
