@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -42,20 +42,21 @@
 #include "magick/studio.h"
 #include "magick/attribute.h"
 #include "magick/blob.h"
-#include "magick/blob_private.h"
-#include "magick/color_private.h"
+#include "magick/blob-private.h"
+#include "magick/color-private.h"
 #include "magick/colorspace.h"
 #include "magick/constitute.h"
 #include "magick/exception.h"
-#include "magick/exception_private.h"
+#include "magick/exception-private.h"
 #include "magick/image.h"
-#include "magick/image_private.h"
+#include "magick/image-private.h"
 #include "magick/list.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/pixel.h"
 #include "magick/static.h"
+#include "magick/statistic.h"
 #include "magick/string_.h"
 
 /*
@@ -223,7 +224,8 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -270,7 +272,7 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
         p=keyword;
         do
         {
-          if ((size_t) (p-keyword) < (MaxTextExtent-1))
+          if ((size_t) (p-keyword) < (MaxTextExtent/2))
             *p++=(char) c;
           c=ReadBlobByte(image);
         } while ((isalnum((int) ((unsigned char) c)) != MagickFalse) ||
@@ -290,7 +292,7 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
         p=value;
         while (isalnum(c) || (c == '-') || (c == '+') || (c == '.'))
         {
-          if ((size_t) (p-value) < (MaxTextExtent-1))
+          if ((size_t) (p-value) < (MaxTextExtent/2))
             *p++=c;
           c=ReadBlobByte(image);
         }
@@ -382,7 +384,7 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
       Convert FITS pixels to pixel packets.
     */
     count=ReadBlob(image,packet_size*image->columns*image->rows,fits_pixels);
-    if (count == 0)
+    if (count != (ssize_t) (packet_size*image->columns*image->rows))
       ThrowReaderException(CorruptImageError,"InsufficientImageDataInFile");
     if ((fits_info.bits_per_pixel > 0) &&
         (fits_info.min_data == 0.0) && (fits_info.max_data == 0.0))
@@ -483,6 +485,9 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
           if (scaled_pixel > fits_info.max_data)
             fits_info.max_data=scaled_pixel;
         }
+        if (fits_info.bits_per_pixel == 16)
+          if (pixel > 32767)
+            pixel-=65536L;
       }
     /*
       Convert FITS pixels to pixel packets.
@@ -542,6 +547,9 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
               *(double *)long_quantum=(-(*(double *) long_quantum));
             pixel=(double) (*((double *) long_quantum));
           }
+        if (fits_info.bits_per_pixel == 16)
+          if (pixel > 32767)
+            pixel-=65536L;
         scaled_pixel=scale*
           (pixel*fits_info.scale-fits_info.min_data-fits_info.zero);
         index=(IndexPacket) ((scaled_pixel < 0.0) ? 0 :
@@ -581,7 +589,7 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
           Allocate next image structure.
         */
         AllocateNextImage(image_info,image);
-        if (image->next == (Image *) NULL)
+        if (GetNextImageInList(image) == (Image *) NULL)
           {
             image=DestroyImageList(image);
             return((Image *) NULL);
@@ -678,7 +686,8 @@ ModuleExport void UnregisterFITSImage(void)
 %
 %  The format of the WriteFITSImage method is:
 %
-%      MagickBooleanType WriteFITSImage(const ImageInfo *image_info,Image *image)
+%      MagickBooleanType WriteFITSImage(const ImageInfo *image_info,
+%        Image *image)
 %
 %  A description of each parameter follows.
 %
@@ -688,7 +697,8 @@ ModuleExport void UnregisterFITSImage(void)
 %
 %
 */
-static MagickBooleanType WriteFITSImage(const ImageInfo *image_info,Image *image)
+static MagickBooleanType WriteFITSImage(const ImageInfo *image_info,
+  Image *image)
 {
   char
     buffer[81],
@@ -723,7 +733,7 @@ static MagickBooleanType WriteFITSImage(const ImageInfo *image_info,Image *image
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
@@ -731,6 +741,8 @@ static MagickBooleanType WriteFITSImage(const ImageInfo *image_info,Image *image
   /*
     Allocate image memory.
   */
+  image->endian=MSBEndian;
+  image->depth=GetImageQuantumDepth(image,MagickTrue);
   packet_size=(size_t) (image->depth > 8 ? 2 : 1);
   fits_info=(char *) AcquireMagickMemory(2880*sizeof(*fits_info));
   pixels=(unsigned char *) AcquireMagickMemory(packet_size*image->columns);
@@ -743,8 +755,8 @@ static MagickBooleanType WriteFITSImage(const ImageInfo *image_info,Image *image
     fits_info[i]=' ';
   (void) strcpy(buffer,"SIMPLE  =                    T");
   (void) strncpy(fits_info+0,buffer,strlen(buffer));
-  (void) FormatMagickString(buffer,MaxTextExtent,
-    "BITPIX  =                    %ld",image->depth);
+  (void) FormatMagickString(buffer,MaxTextExtent,"BITPIX  =           %10lu",
+    image->depth);
   (void) strncpy(fits_info+80,buffer,strlen(buffer));
   (void) strcpy(buffer,"NAXIS   =                    2");
   (void) strncpy(fits_info+160,buffer,strlen(buffer));
@@ -759,10 +771,13 @@ static MagickBooleanType WriteFITSImage(const ImageInfo *image_info,Image *image
   (void) FormatMagickString(buffer,MaxTextExtent,"DATAMAX =           %10u",
     (1 << image->depth)-1);
   (void) strncpy(fits_info+480,buffer,strlen(buffer));
-  (void) strcpy(buffer,"HISTORY Created by ImageMagick.");
+  (void) FormatMagickString(buffer,MaxTextExtent,"BZERO   =           %10u",
+    image->depth > 8 ? 32768 : 0);
   (void) strncpy(fits_info+560,buffer,strlen(buffer));
-  (void) strcpy(buffer,"END");
+  (void) strcpy(buffer,"HISTORY Created by ImageMagick.");
   (void) strncpy(fits_info+640,buffer,strlen(buffer));
+  (void) strcpy(buffer,"END");
+  (void) strncpy(fits_info+720,buffer,strlen(buffer));
   (void) WriteBlob(image,2880,(unsigned char *) fits_info);
   /*
     Convert image to fits scale PseudoColor class.
