@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -42,19 +42,20 @@
 #include "magick/studio.h"
 #include "magick/attribute.h"
 #include "magick/blob.h"
-#include "magick/blob_private.h"
+#include "magick/blob-private.h"
 #include "magick/color.h"
-#include "magick/color_private.h"
+#include "magick/color-private.h"
 #include "magick/constitute.h"
 #include "magick/exception.h"
-#include "magick/exception_private.h"
+#include "magick/exception-private.h"
 #include "magick/geometry.h"
-#include "magick/image_private.h"
+#include "magick/image-private.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/resource_.h"
 #include "magick/static.h"
+#include "magick/statistic.h"
 #include "magick/string_.h"
 
 /*
@@ -211,7 +212,8 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   (void) SetImageDepth(image,image->depth);
   SetGeometry(image,&geometry);
   if (image_info->density == (char *) NULL)
@@ -226,7 +228,7 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
   /*
     Allocate histogram count arrays.
   */
-  length=(size_t) Max((unsigned long) ScaleQuantumToChar(MaxRGB)+1,
+  length=(size_t) Max((unsigned long) ScaleQuantumToChar(QuantumRange)+1,
     histogram_image->columns);
   histogram=(MagickPixelPacket *)
     AcquireMagickMemory(length*sizeof(*histogram));
@@ -268,7 +270,7 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
   */
   (void) QueryColorDatabase("#000000",&histogram_image->background_color,
     &image->exception);
-  SetImage(histogram_image,OpaqueOpacity);
+  SetImageBackgroundColor(histogram_image);
   for (x=0; x < (long) histogram_image->columns; x++)
   {
     q=GetImagePixels(histogram_image,x,0,1,histogram_image->rows);
@@ -278,21 +280,21 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
     r=q+y;
     for ( ; y < (long) histogram_image->rows; y++)
     {
-      r->red=MaxRGB;
+      r->red=QuantumRange;
       r++;
     }
     y=(long) (histogram_image->rows-scale*histogram[x].green+0.5);
     r=q+y;
     for ( ; y < (long) histogram_image->rows; y++)
     {
-      r->green=MaxRGB;
+      r->green=QuantumRange;
       r++;
     }
     y=(long) (histogram_image->rows-scale*histogram[x].blue+0.5);
     r=q+y;
     for ( ; y < (long) histogram_image->rows; y++)
     {
-      r->blue=MaxRGB;
+      r->blue=QuantumRange;
       r++;
     }
     if (SyncImagePixels(histogram_image) == MagickFalse)
