@@ -466,6 +466,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   code=0;
   *id='\0';
+  (void) ResetMagickMemory(keyword,0,sizeof(keyword));
   version=0.0;
   do
   {
@@ -530,7 +531,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                 break;
               if (c == (int) '=')
                 break;
-              if ((size_t) (p-keyword) < (MaxTextExtent-1))
+              if ((size_t) (p-keyword) < (MaxTextExtent/2))
                 *p++=(char) c;
               c=ReadBlobByte(image);
             } while (c != EOF);
