@@ -308,6 +308,7 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
   */
   (void) ResetMagickMemory(&bounds,0,sizeof(bounds));
   (void) ResetMagickMemory(&page,0,sizeof(page));
+  (void) ResetMagickMemory(command,0,sizeof(command));
   iptc_profile=(StringInfo *) NULL;
   xml_profile=(StringInfo *) NULL;
   skip=MagickFalse;
@@ -320,7 +321,7 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
       Note document structuring comments.
     */
     *p++=(char) c;
-    if ((c != (int) '%') && ((size_t) (p-command) < (MaxTextExtent-1)))
+    if ((c != (int) '%') && ((size_t) (p-command) < (MaxTextExtent/2)))
       continue;
     *p='\0';
     p=command;
