@@ -927,7 +927,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
           Convert tiled TIFF image to DirectClass MIFF image.
         */
         if ((TIFFGetField(tiff,TIFFTAG_TILEWIDTH,&columns) == 0) ||
-           (TIFFGetField(tiff,TIFFTAG_TILELENGTH,&rows) == 0))
+            (TIFFGetField(tiff,TIFFTAG_TILELENGTH,&rows) == 0))
           {
             TIFFClose(tiff);
             ThrowReaderException(CoderError,"ImageIsNotTiled");
@@ -1470,7 +1470,7 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
 
   unsigned long
     lsb_first,
-    strip_size;
+    rows_per_strip;
 
   /*
     Open TIFF file.
@@ -1705,13 +1705,13 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
       if ((image_info->interlace == PlaneInterlace) ||
           (image_info->interlace == PartitionInterlace))
         (void) TIFFSetField(tiff,TIFFTAG_PLANARCONFIG,PLANARCONFIG_SEPARATE);
-    strip_size=(unsigned long) Max(TIFFDefaultStripSize(tiff,-1),1);
+    rows_per_strip=(unsigned long) Max(TIFFDefaultStripSize(tiff,-1),1);
     switch (compress_tag)
     {
       case COMPRESSION_JPEG:
       {
         (void) TIFFSetField(tiff,TIFFTAG_ROWSPERSTRIP,
-          strip_size+(16-(strip_size % 16)));
+          rows_per_strip+(16-(rows_per_strip % 16)));
         break;
       }
       case COMPRESSION_ADOBE_DEFLATE:
@@ -1733,7 +1733,7 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
       }
       case COMPRESSION_LZW:
       {
-        (void) TIFFSetField(tiff,TIFFTAG_ROWSPERSTRIP,strip_size);
+        (void) TIFFSetField(tiff,TIFFTAG_ROWSPERSTRIP,rows_per_strip);
         (void) TIFFGetFieldDefaulted(tiff,TIFFTAG_BITSPERSAMPLE,
           &bits_per_sample);
         if (((photometric == PHOTOMETRIC_RGB) ||
@@ -1744,7 +1744,7 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
       }
       default:
       {
-        (void) TIFFSetField(tiff,TIFFTAG_ROWSPERSTRIP,strip_size);
+        (void) TIFFSetField(tiff,TIFFTAG_ROWSPERSTRIP,rows_per_strip);
         break;
       }
     }
