@@ -207,7 +207,7 @@ static MagickBooleanType
 */
 MagickExport void DestroyCoderList(void)
 {
-  coder_semaphore=AcquireSemaphoreInfo(coder_semaphore);
+  AcquireSemaphoreInfo(&coder_semaphore);
   if (coder_list != (SplayTreeInfo *) NULL)
     coder_list=DestroySplayTree(coder_list);
   instantiate_coder=MagickFalse;
@@ -263,7 +263,7 @@ MagickExport const CoderInfo *GetCoderInfo(const char *name,
   /*
     Search for requested coder.
   */
-  coder_semaphore=AcquireSemaphoreInfo(coder_semaphore);
+  AcquireSemaphoreInfo(&coder_semaphore);
   ResetSplayTreeIterator(coder_list);
   p=(const CoderInfo *) GetNextValueInSplayTree(coder_list);
   while (p != (const CoderInfo *) NULL)
@@ -347,7 +347,7 @@ MagickExport const CoderInfo **GetCoderInfoList(const char *pattern,
   /*
     Generate coder list.
   */
-  coder_semaphore=AcquireSemaphoreInfo(coder_semaphore);
+  AcquireSemaphoreInfo(&coder_semaphore);
   ResetSplayTreeIterator(coder_list);
   p=(const CoderInfo *) GetNextValueInSplayTree(coder_list);
   for (i=0; p != (const CoderInfo *) NULL; )
@@ -432,7 +432,7 @@ MagickExport char **GetCoderList(const char *pattern,
   /*
     Generate coder list.
   */
-  coder_semaphore=AcquireSemaphoreInfo(coder_semaphore);
+  AcquireSemaphoreInfo(&coder_semaphore);
   ResetSplayTreeIterator(coder_list);
   p=(const CoderInfo *) GetNextValueInSplayTree(coder_list);
   for (i=0; p != (const CoderInfo *) NULL; )
@@ -476,7 +476,7 @@ static MagickBooleanType InitializeCoderList(ExceptionInfo *exception)
   if ((coder_list == (SplayTreeInfo *) NULL) &&
       (instantiate_coder == MagickFalse))
     {
-      coder_semaphore=AcquireSemaphoreInfo(coder_semaphore);
+      AcquireSemaphoreInfo(&coder_semaphore);
       if ((coder_list == (SplayTreeInfo *) NULL) &&
           (instantiate_coder == MagickFalse))
         {
