@@ -439,8 +439,9 @@ MagickExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
           (exception->severity < ErrorException);
         if (image == (Image *) NULL)
           {
-            if (image_stack[k] != (Image *) NULL)
-              InheritException(&image_stack[k]->exception,exception);
+            if (image_stack[k] == (Image *) NULL)
+              break;
+            InheritException(&image_stack[k]->exception,exception);
             continue;
           }
         GetImageException(image,exception);
