@@ -382,7 +382,7 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
       (GetMagickDecoder(magick_info) != (DecoderHandler *) NULL))
     {
       if (GetMagickThreadSupport(magick_info) == MagickFalse)
-        constitute_semaphore=AcquireSemaphoreInfo(constitute_semaphore);
+        AcquireSemaphoreInfo(&constitute_semaphore);
       image=GetMagickDecoder(magick_info)(read_info,exception);
       if (GetMagickThreadSupport(magick_info) == MagickFalse)
         RelinquishSemaphoreInfo(constitute_semaphore);
@@ -439,7 +439,7 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
           return((Image *) NULL);
         }
       if (GetMagickThreadSupport(magick_info) == MagickFalse)
-        constitute_semaphore=AcquireSemaphoreInfo(constitute_semaphore);
+        AcquireSemaphoreInfo(&constitute_semaphore);
       image=(Image *) (GetMagickDecoder(magick_info))(read_info,exception);
       if (GetMagickThreadSupport(magick_info) == MagickFalse)
         RelinquishSemaphoreInfo(constitute_semaphore);
@@ -911,7 +911,7 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
         Call appropriate image writer based on image type.
       */
       if (GetMagickThreadSupport(magick_info) == MagickFalse)
-        constitute_semaphore=AcquireSemaphoreInfo(constitute_semaphore);
+        AcquireSemaphoreInfo(&constitute_semaphore);
       status=GetMagickEncoder(magick_info)(write_info,image);
       if (GetMagickThreadSupport(magick_info) == MagickFalse)
         RelinquishSemaphoreInfo(constitute_semaphore);
@@ -952,7 +952,7 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
                 Call appropriate image writer based on image type.
               */
               if (GetMagickThreadSupport(magick_info) == MagickFalse)
-                constitute_semaphore=AcquireSemaphoreInfo(constitute_semaphore);
+                AcquireSemaphoreInfo(&constitute_semaphore);
               status=GetMagickEncoder(magick_info)(write_info,image);
               if (GetMagickThreadSupport(magick_info) == MagickFalse)
                 RelinquishSemaphoreInfo(constitute_semaphore);
