@@ -1069,8 +1069,9 @@ MagickExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
           (exception->severity < ErrorException);
         if (image == (Image *) NULL)
           {
-            if (image_stack[k] != (Image *) NULL)
-              InheritException(&image_stack[k]->exception,exception);
+            if (image_stack[k] == (Image *) NULL)
+              break;
+            InheritException(&image_stack[k]->exception,exception);
             continue;
           }
         GetImageException(image,exception);
@@ -1215,9 +1216,6 @@ MagickExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
       {
         if (LocaleCompare("format",option+1) == 0)
           {
-            register char
-              *q;
-
             format=(char *) NULL;
             if (*option == '+')
               break;
@@ -1225,11 +1223,6 @@ MagickExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
             if (i == (long) argc)
               ThrowIdentifyException(OptionError,"MissingArgument",option);
             format=argv[i];
-            image_info->ping=MagickTrue;
-            for (q=strchr(format,'%'); q != (char *) NULL; q=strchr(q+1,'%'))
-              if ((*(q+1) == 'g') || (*(q+1) == 'k') || (*(q+1) == 'r') ||
-                  (*(q+1) == 'z') || (*(q+1) == '@') || (*(q+1) == '#'))
-                image_info->ping=MagickFalse;
             break;
           }
         if (LocaleCompare("fuzz",option+1) == 0)
