@@ -449,8 +449,9 @@ MagickExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
             (exception->severity < ErrorException);
           if (image == (Image *) NULL)
             {
-              if (image_stack[k] != (Image *) NULL)
-                InheritException(&image_stack[k]->exception,exception);
+              if (image_stack[k] == (Image *) NULL)
+                break;
+              InheritException(&image_stack[k]->exception,exception);
               continue;
             }
           (void) CopyMagickString(image->filename,filename,MaxTextExtent);
