@@ -5,7 +5,7 @@
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
   
-    http://www.imagemagick.org/www/Copyright.html
+    http://www.imagemagick.org/script/license.php
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -50,6 +50,7 @@ extern "C" {
 #define AcquireUniqueFilename  PrependMagickMethod(AcquireUniqueFilename)
 #define AcquireUniqueFileResource  PrependMagickMethod(AcquireUniqueFileResource)
 #define AdaptiveThresholdImage  PrependMagickMethod(AdaptiveThresholdImage)
+#define AddValueToSplayTree  PrependMagickMethod(AddValueToSplayTree)
 #define AddNoiseImage  PrependMagickMethod(AddNoiseImage)
 #define AffineTransformImage  PrependMagickMethod(AffineTransformImage)
 #define AllocateImageColormap  PrependMagickMethod(AllocateImageColormap)
@@ -57,10 +58,11 @@ extern "C" {
 #define AllocateNextImage  PrependMagickMethod(AllocateNextImage)
 #define AllocateSemaphoreInfo  PrependMagickMethod(AllocateSemaphoreInfo)
 #define AllocateString  PrependMagickMethod(AllocateString)
+#define AnalyzeImage  PrependMagickMethod(AnalyzeImage)
 #define AnimateImageCommand  PrependMagickMethod(AnimateImageCommand)
 #define AnimateImages  PrependMagickMethod(AnimateImages)
 #define AnnotateImage  PrependMagickMethod(AnnotateImage)
-#define AppendElementToLinkedList  PrependMagickMethod(AppendElementToLinkedList)
+#define AppendValueToLinkedList  PrependMagickMethod(AppendValueToLinkedList)
 #define AppendImageFormat  PrependMagickMethod(AppendImageFormat)
 #define AppendImages  PrependMagickMethod(AppendImages)
 #define AppendImageToList  PrependMagickMethod(AppendImageToList)
@@ -109,9 +111,13 @@ extern "C" {
 #define ColorFloodfillImage  PrependMagickMethod(ColorFloodfillImage)
 #define ColorizeImage  PrependMagickMethod(ColorizeImage)
 #define CombineImages  PrependMagickMethod(CombineImages)
+#define CompareHashmapStringInfo  PrependMagickMethod(CompareHashmapStringInfo)
+#define CompareHashmapString  PrependMagickMethod(CompareHashmapString)
 #define CompareImageChannels  PrependMagickMethod(CompareImageChannels)
 #define CompareImageCommand  PrependMagickMethod(CompareImageCommand)
 #define CompareImages  PrependMagickMethod(CompareImages)
+#define CompareSplayTreeStringInfo  PrependMagickMethod(CompareSplayTreeStringInfo)
+#define CompareSplayTreeString  PrependMagickMethod(CompareSplayTreeString)
 #define CompareStringInfo  PrependMagickMethod(CompareStringInfo)
 #define CompositeImageCommand  PrependMagickMethod(CompositeImageCommand)
 #define CompositeImage  PrependMagickMethod(CompositeImage)
@@ -121,6 +127,7 @@ extern "C" {
 #define ConcatenateString  PrependMagickMethod(ConcatenateString)
 #define ConjureImageCommand  PrependMagickMethod(ConjureImageCommand)
 #define ConsolidateCMYKImages  PrependMagickMethod(ConsolidateCMYKImages)
+#define ConstantString  PrependMagickMethod(ConstantString)
 #define ConstituteImage  PrependMagickMethod(ConstituteImage)
 #define ContinueTimer  PrependMagickMethod(ContinueTimer)
 #define ContrastImage  PrependMagickMethod(ContrastImage)
@@ -135,6 +142,7 @@ extern "C" {
 #define DeconstructImages  PrependMagickMethod(DeconstructImages)
 #define DefineImageOption  PrependMagickMethod(DefineImageOption)
 #define DeleteImageFromList  PrependMagickMethod(DeleteImageFromList)
+#define DeleteImageList  PrependMagickMethod(DeleteImageList)
 #define DeleteImageOption  PrependMagickMethod(DeleteImageOption)
 #define DeleteMagickRegistry  PrependMagickMethod(DeleteMagickRegistry)
 #define DescribeImage  PrependMagickMethod(DescribeImage)
@@ -174,6 +182,7 @@ extern "C" {
 #define DestroyRandomReservoir  PrependMagickMethod(DestroyRandomReservoir)
 #define DestroySemaphoreInfo  PrependMagickMethod(DestroySemaphoreInfo)
 #define DestroySemaphore  PrependMagickMethod(DestroySemaphore)
+#define DestroySplayTree  PrependMagickMethod(DestroySplayTree)
 #define DestroyStringInfo  PrependMagickMethod(DestroyStringInfo)
 #define DestroyStringList  PrependMagickMethod(DestroyStringList)
 #define DestroyString  PrependMagickMethod(DestroyString)
@@ -262,8 +271,8 @@ extern "C" {
 #define GetDelegateMode  PrependMagickMethod(GetDelegateMode)
 #define GetDrawInfo  PrependMagickMethod(GetDrawInfo)
 #define GetElapsedTime  PrependMagickMethod(GetElapsedTime)
-#define GetElementFromLinkedList  PrependMagickMethod(GetElementFromLinkedList)
-#define GetEntryFromHashmap  PrependMagickMethod(GetEntryFromHashmap)
+#define GetValueFromLinkedList  PrependMagickMethod(GetValueFromLinkedList)
+#define GetValueFromHashmap  PrependMagickMethod(GetValueFromHashmap)
 #define GetExceptionInfo  PrependMagickMethod(GetExceptionInfo)
 #define GetExecutionPath  PrependMagickMethod(GetExecutionPath)
 #define GetFirstImageInList  PrependMagickMethod(GetFirstImageInList)
@@ -302,14 +311,16 @@ extern "C" {
 #define GetImageType  PrependMagickMethod(GetImageType)
 #define GetImageVirtualPixelMethod  PrependMagickMethod(GetImageVirtualPixelMethod)
 #define GetIndexes  PrependMagickMethod(GetIndexes)
-#define GetLastElementInLinkedList  PrependMagickMethod(GetLastElementInLinkedList)
+#define GetLastValueInLinkedList  PrependMagickMethod(GetLastValueInLinkedList)
 #define GetLastImageInList  PrependMagickMethod(GetLastImageInList)
 #define GetLocaleExceptionMessage  PrependMagickMethod(GetLocaleExceptionMessage)
 #define GetLocaleInfoList  PrependMagickMethod(GetLocaleInfoList)
 #define GetLocaleInfo_  PrependMagickMethod(GetLocaleInfo_)
 #define GetLocaleList  PrependMagickMethod(GetLocaleList)
 #define GetLocaleMessage  PrependMagickMethod(GetLocaleMessage)
+#define GetLocaleMonitorMessage  PrependMagickMethod(GetLocaleMonitorMessage)
 #define GetLocaleOptions  PrependMagickMethod(GetLocaleOptions)
+#define GetLocaleValue  PrependMagickMethod(GetLocaleValue)
 #define GetLogInfoList  PrependMagickMethod(GetLogInfoList)
 #define GetLogInfo  PrependMagickMethod(GetLogInfo)
 #define GetLogList  PrependMagickMethod(GetLogList)
@@ -342,18 +353,21 @@ extern "C" {
 #define GetMonitorHandler  PrependMagickMethod(GetMonitorHandler)
 #define GetMontageInfo  PrependMagickMethod(GetMontageInfo)
 #define GetMultilineTypeMetrics  PrependMagickMethod(GetMultilineTypeMetrics)
-#define GetNextElementInLinkedList  PrependMagickMethod(GetNextElementInLinkedList)
-#define GetNextEntryInHashmap  PrependMagickMethod(GetNextEntryInHashmap)
+#define GetNextValueInLinkedList  PrependMagickMethod(GetNextValueInLinkedList)
+#define GetNextKeyInHashmap  PrependMagickMethod(GetNextKeyInHashmap)
 #define GetNextImageInList  PrependMagickMethod(GetNextImageInList)
 #define GetNextImageOption  PrependMagickMethod(GetNextImageOption)
 #define GetNextImage  PrependMagickMethod(GetNextImage)
 #define GetNextImageProfile  PrependMagickMethod(GetNextImageProfile)
+#define GetNextValueInSplayTree  PrependMagickMethod(GetNextValueInSplayTree)
 #define GetNexusIndexes  PrependMagickMethod(GetNexusIndexes)
 #define GetNexusPixels  PrependMagickMethod(GetNexusPixels)
 #define GetNexus  PrependMagickMethod(GetNexus)
+#define GetValueFromSplayTree  PrependMagickMethod(GetValueFromSplayTree)
 #define GetNumberColors  PrependMagickMethod(GetNumberColors)
 #define GetNumberOfElementsInLinkedList  PrependMagickMethod(GetNumberOfElementsInLinkedList)
 #define GetNumberOfEntriesInHashmap  PrependMagickMethod(GetNumberOfEntriesInHashmap)
+#define GetNumberOfNodesInSplayTree  PrependMagickMethod(GetNumberOfNodesInSplayTree)
 #define GetNumberScenes  PrependMagickMethod(GetNumberScenes)
 #define GetOnePixel  PrependMagickMethod(GetOnePixel)
 #define GetOptimalKernelWidth1D  PrependMagickMethod(GetOptimalKernelWidth1D)
@@ -370,7 +384,7 @@ extern "C" {
 #define GetRandomValue  PrependMagickMethod(GetRandomValue)
 #define GetSignatureInfo  PrependMagickMethod(GetSignatureInfo)
 #define GetTimerInfo  PrependMagickMethod(GetTimerInfo)
-#define GetToken  PrependMagickMethod(GetToken)
+#define GetMagickToken  PrependMagickMethod(GetMagickToken)
 #define GetTypeInfoByFamily  PrependMagickMethod(GetTypeInfoByFamily)
 #define GetTypeInfoList  PrependMagickMethod(GetTypeInfoList)
 #define GetTypeInfo  PrependMagickMethod(GetTypeInfo)
@@ -390,6 +404,7 @@ extern "C" {
 #define Hull  PrependMagickMethod(Hull)
 #define HWBTransform  PrependMagickMethod(HWBTransform)
 #define IdentifyImageCommand  PrependMagickMethod(IdentifyImageCommand)
+#define IdentifyImage  PrependMagickMethod(IdentifyImage)
 #define IdentityAffine  PrependMagickMethod(IdentityAffine)
 #define ImageListToArray  PrependMagickMethod(ImageListToArray)
 #define ImagesToBlob  PrependMagickMethod(ImagesToBlob)
@@ -403,8 +418,8 @@ extern "C" {
 #define InitializeMagick  PrependMagickMethod(InitializeMagick)
 #define InitializeMagickResources  PrependMagickMethod(InitializeMagickResources)
 #define InitializeSemaphore  PrependMagickMethod(InitializeSemaphore)
-#define InsertElementInLinkedList  PrependMagickMethod(InsertElementInLinkedList)
-#define InsertElementInSortedLinkedList  PrependMagickMethod(InsertElementInSortedLinkedList)
+#define InsertValueInLinkedList  PrependMagickMethod(InsertValueInLinkedList)
+#define InsertValueInSortedLinkedList  PrependMagickMethod(InsertValueInSortedLinkedList)
 #define InsertImageInList  PrependMagickMethod(InsertImageInList)
 #define InterpolateColor  PrependMagickMethod(InterpolateColor)
 #define InvokeDelegate  PrependMagickMethod(InvokeDelegate)
@@ -447,6 +462,7 @@ extern "C" {
 #define ListMagickInfo  PrependMagickMethod(ListMagickInfo)
 #define ListMagickResourceInfo  PrependMagickMethod(ListMagickResourceInfo)
 #define ListTypeInfo  PrependMagickMethod(ListTypeInfo)
+#define LoadWPG2Flags  PrependMagickMethod(LoadWPG2Flags)
 #define LocaleCompare  PrependMagickMethod(LocaleCompare)
 #define LocaleLower  PrependMagickMethod(LocaleLower)
 #define LocaleNCompare  PrependMagickMethod(LocaleNCompare)
@@ -456,6 +472,7 @@ extern "C" {
 #define LZWEncodeImage  PrependMagickMethod(LZWEncodeImage)
 #define MagickError  PrependMagickMethod(MagickError)
 #define MagickFatalError  PrependMagickMethod(MagickFatalError)
+#define MagickIncarnate  PrependMagickMethod(MagickIncarnate)
 #define MagickMonitor  PrependMagickMethod(MagickMonitor)
 #define MagickOptionToMnemonic  PrependMagickMethod(MagickOptionToMnemonic)
 #define MagickToMime  PrependMagickMethod(MagickToMime)
@@ -491,6 +508,7 @@ extern "C" {
 #define NewImageList  PrependMagickMethod(NewImageList)
 #define NewLinkedList  PrependMagickMethod(NewLinkedList)
 #define NewMagickImage  PrependMagickMethod(NewMagickImage)
+#define NewSplayTree  PrependMagickMethod(NewSplayTree)
 #define NormalizeImageChannel  PrependMagickMethod(NormalizeImageChannel)
 #define NormalizeImage  PrependMagickMethod(NormalizeImage)
 #define OilPaintImage  PrependMagickMethod(OilPaintImage)
@@ -515,6 +533,7 @@ extern "C" {
 #define PingImage  PrependMagickMethod(PingImage)
 #define PlasmaImage  PrependMagickMethod(PlasmaImage)
 #define PopImageList  PrependMagickMethod(PopImageList)
+#define PopImagePixels  PrependMagickMethod(PopImagePixels)
 #define PosterizeImage  PrependMagickMethod(PosterizeImage)
 #define PostscriptGeometry  PrependMagickMethod(PostscriptGeometry)
 #define PrependImageToList  PrependMagickMethod(PrependImageToList)
@@ -522,6 +541,7 @@ extern "C" {
 #define PrintStringInfo  PrependMagickMethod(PrintStringInfo)
 #define ProfileImage  PrependMagickMethod(ProfileImage)
 #define PushImageList  PrependMagickMethod(PushImageList)
+#define PushImagePixels  PrependMagickMethod(PushImagePixels)
 #define PutEntryInHashmap  PrependMagickMethod(PutEntryInHashmap)
 #define QuantizationError  PrependMagickMethod(QuantizationError)
 #define QuantizeImage  PrependMagickMethod(QuantizeImage)
@@ -533,6 +553,7 @@ extern "C" {
 #define RaiseImage  PrependMagickMethod(RaiseImage)
 #define RandomChannelThresholdImage  PrependMagickMethod(RandomChannelThresholdImage)
 #define RandomThresholdImageChannel  PrependMagickMethod(RandomThresholdImageChannel)
+#define RandomThresholdImage  PrependMagickMethod(RandomThresholdImage)
 #define ReacquireMemory  PrependMagickMethod(ReacquireMemory)
 #define ReadBlobByte  PrependMagickMethod(ReadBlobByte)
 #define ReadBlobLSBLong  PrependMagickMethod(ReadBlobLSBLong)
@@ -560,6 +581,7 @@ extern "C" {
 #define RegisterCUTImage  PrependMagickMethod(RegisterCUTImage)
 #define RegisterDCMImage  PrependMagickMethod(RegisterDCMImage)
 #define RegisterDIBImage  PrependMagickMethod(RegisterDIBImage)
+#define RegisterDOTImage  PrependMagickMethod(RegisterDOTImage)
 #define RegisterDPSImage  PrependMagickMethod(RegisterDPSImage)
 #define RegisterDPXImage  PrependMagickMethod(RegisterDPXImage)
 #define RegisterEPTImage  PrependMagickMethod(RegisterEPTImage)
@@ -656,12 +678,15 @@ extern "C" {
 #define RemoveImageProfile  PrependMagickMethod(RemoveImageProfile)
 #define RemoveLastElementFromLinkedList  PrependMagickMethod(RemoveLastElementFromLinkedList)
 #define RemoveLastImageFromList  PrependMagickMethod(RemoveLastImageFromList)
+#define RemoveNodeByValueFromSplayTree  PrependMagickMethod(RemoveNodeByValueFromSplayTree)
+#define RemoveNodeFromSplayTree  PrependMagickMethod(RemoveNodeFromSplayTree)
 #define ReplaceImageInList  PrependMagickMethod(ReplaceImageInList)
 #define ResetHashmapIterator  PrependMagickMethod(ResetHashmapIterator)
 #define ResetImageOptionIterator  PrependMagickMethod(ResetImageOptionIterator)
 #define ResetImageProfileIterator  PrependMagickMethod(ResetImageProfileIterator)
 #define ResetLinkedListIterator  PrependMagickMethod(ResetLinkedListIterator)
 #define ResetMagickMemory  PrependMagickMethod(ResetMagickMemory)
+#define ResetSplayTreeIterator  PrependMagickMethod(ResetSplayTreeIterator)
 #define ResetStringInfo  PrependMagickMethod(ResetStringInfo)
 #define ResetTimer  PrependMagickMethod(ResetTimer)
 #define ResizeImage  PrependMagickMethod(ResizeImage)
@@ -687,6 +712,7 @@ extern "C" {
 #define SetGeometryInfo  PrependMagickMethod(SetGeometryInfo)
 #define SetGeometry  PrependMagickMethod(SetGeometry)
 #define SetImageAttribute  PrependMagickMethod(SetImageAttribute)
+#define SetImageBackgroundColor  PrependMagickMethod(SetImageBackgroundColor)
 #define SetImageChannelDepth  PrependMagickMethod(SetImageChannelDepth)
 #define SetImageClipMask  PrependMagickMethod(SetImageClipMask)
 #define SetImageColorspace  PrependMagickMethod(SetImageColorspace)
@@ -697,7 +723,6 @@ extern "C" {
 #define SetImageOpacity  PrependMagickMethod(SetImageOpacity)
 #define SetImageOption  PrependMagickMethod(SetImageOption)
 #define SetImagePixels  PrependMagickMethod(SetImagePixels)
-#define SetImage  PrependMagickMethod(SetImage)
 #define SetImageProfile  PrependMagickMethod(SetImageProfile)
 #define SetImageProgressMonitor  PrependMagickMethod(SetImageProgressMonitor)
 #define SetImageType  PrependMagickMethod(SetImageType)
@@ -786,6 +811,7 @@ extern "C" {
 #define UnregisterCUTImage  PrependMagickMethod(UnregisterCUTImage)
 #define UnregisterDCMImage  PrependMagickMethod(UnregisterDCMImage)
 #define UnregisterDIBImage  PrependMagickMethod(UnregisterDIBImage)
+#define UnregisterDOTImage  PrependMagickMethod(UnregisterDOTImage)
 #define UnregisterDPSImage  PrependMagickMethod(UnregisterDPSImage)
 #define UnregisterDPXImage  PrependMagickMethod(UnregisterDPXImage)
 #define UnregisterEPTImage  PrependMagickMethod(UnregisterEPTImage)
