@@ -135,7 +135,7 @@ MagickExport void DestroyModuleList(void)
   /*
     Deestroy magick modules.
   */
-  module_semaphore=AcquireSemaphoreInfo(module_semaphore);
+  AcquireSemaphoreInfo(&module_semaphore);
 #if defined(SupportMagickModules)
   if (module_list != (SplayTreeInfo *) NULL)
     module_list=DestroySplayTree(module_list);
@@ -302,7 +302,7 @@ MagickExport const ModuleInfo *GetModuleInfo(const char *tag,
       ResetSplayTreeIterator(module_list);
       return((const ModuleInfo *) GetNextValueInSplayTree(module_list));
     }
-  module_semaphore=AcquireSemaphoreInfo(module_semaphore);
+  AcquireSemaphoreInfo(&module_semaphore);
   ResetSplayTreeIterator(module_list);
   p=(const ModuleInfo *) GetNextValueInSplayTree(module_list);
   while (p != (const ModuleInfo *) NULL)
@@ -396,7 +396,7 @@ MagickExport const ModuleInfo **GetModuleInfoList(const char *pattern,
   /*
     Generate module list.
   */
-  module_semaphore=AcquireSemaphoreInfo(module_semaphore);
+  AcquireSemaphoreInfo(&module_semaphore);
   ResetSplayTreeIterator(module_list);
   p=(const ModuleInfo *) GetNextValueInSplayTree(module_list);
   for (i=0; p != (const ModuleInfo *) NULL; )
@@ -871,7 +871,7 @@ static MagickBooleanType InitializeModuleList(ExceptionInfo *exception)
   if ((module_list == (SplayTreeInfo *) NULL) &&
       (instantiate_module == MagickFalse))
     {
-      module_semaphore=AcquireSemaphoreInfo(module_semaphore);
+      AcquireSemaphoreInfo(&module_semaphore);
       if ((module_list == (SplayTreeInfo *) NULL) &&
           (instantiate_module == MagickFalse))
         {
