@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/www/Copyright.html                            %
+%    http://www.imagemagick.org/script/license.php                            %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -180,7 +180,7 @@
 #include "magick/colorspace.h"
 #include "magick/enhance.h"
 #include "magick/exception.h"
-#include "magick/exception_private.h"
+#include "magick/exception-private.h"
 #include "magick/image.h"
 #include "magick/list.h"
 #include "magick/memory_.h"
@@ -275,6 +275,12 @@ typedef struct _CubeInfo
 
   unsigned long
     depth;
+
+  MagickOffsetType
+    offset;
+
+  MagickOffsetType
+    span;
 } CubeInfo;
 
 /*
@@ -424,8 +430,8 @@ static MagickBooleanType AssignImageColors(CubeInfo *cube_info,Image *image)
         cube_info->color.red=(double) q->red;
         cube_info->color.green=(double) q->green;
         cube_info->color.blue=(double) q->blue;
-        cube_info->distance=3.0*((MagickRealType) MaxRGB+1.0)*
-          ((MagickRealType) MaxRGB+1.0);
+        cube_info->distance=3.0*((MagickRealType) QuantumRange+1.0)*
+          ((MagickRealType) QuantumRange+1.0);
         ClosestColor(image,cube_info,node_info->parent);
         index=(IndexPacket) cube_info->color_number;
         for (i=0; i < count; i++)
@@ -465,7 +471,7 @@ static MagickBooleanType AssignImageColors(CubeInfo *cube_info,Image *image)
       for (i=0; i < (long) image->colors; i++)
       {
         intensity=(Quantum) ((unsigned long) PixelIntensityToQuantum(q) <
-          (MaxRGB/2) ? 0 : MaxRGB);
+          (QuantumRange/2) ? 0 : QuantumRange);
         q->red=intensity;
         q->green=intensity;
         q->blue=intensity;
@@ -599,10 +605,10 @@ static MagickBooleanType ClassifyImageColors(CubeInfo *cube_info,
         if (ColorMatch(p,p+count) == MagickFalse)
           break;
       index=MaxTreeDepth-1;
-      bisect=((MagickRealType) MaxRGB+1.0)/2.0;
-      mid.red=(double) MaxRGB/2.0;
-      mid.green=(double) MaxRGB/2.0;
-      mid.blue=(double) MaxRGB/2.0;
+      bisect=((MagickRealType) QuantumRange+1.0)/2.0;
+      mid.red=(double) QuantumRange/2.0;
+      mid.green=(double) QuantumRange/2.0;
+      mid.blue=(double) QuantumRange/2.0;
       node_info=cube_info->root;
       for (level=1; level <= MaxTreeDepth; level++)
       {
@@ -619,7 +625,8 @@ static MagickBooleanType ClassifyImageColors(CubeInfo *cube_info,
             node_info->child[id]=GetNodeInfo(cube_info,id,level,node_info);
             if (node_info->child[id] == (NodeInfo *) NULL)
               (void) ThrowMagickException(exception,GetMagickModule(),
-                ResourceLimitError,"MemoryAllocationFailed",image->filename);
+                ResourceLimitError,"MemoryAllocationFailed","`%s'",
+                image->filename);
             if (level == MaxTreeDepth)
               cube_info->colors++;
           }
@@ -681,10 +688,10 @@ static MagickBooleanType ClassifyImageColors(CubeInfo *cube_info,
         if (ColorMatch(p,p+count) == MagickFalse)
           break;
       index=MaxTreeDepth-1;
-      bisect=((MagickRealType) MaxRGB+1.0)/2.0;
-      mid.red=(double) MaxRGB/2.0;
-      mid.green=(double) MaxRGB/2.0;
-      mid.blue=(double) MaxRGB/2.0;
+      bisect=((MagickRealType) QuantumRange+1.0)/2.0;
+      mid.red=(double) QuantumRange/2.0;
+      mid.green=(double) QuantumRange/2.0;
+      mid.blue=(double) QuantumRange/2.0;
       node_info=cube_info->root;
       for (level=1; level <= cube_info->depth; level++)
       {
@@ -894,7 +901,7 @@ MagickExport void CompressImageColormap(Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (IsPaletteImage(image,&image->exception) == MagickFalse)
     return;
   GetQuantizeInfo(&quantize_info);
@@ -952,11 +959,11 @@ static void DefineImageColormap(Image *image,NodeInfo *node_info)
       */
       number_unique=(double) ((MagickOffsetType) node_info->number_unique);
       image->colormap[image->colors].red=(Quantum)
-        (MaxRGB*node_info->total_red/number_unique+0.5);
+        (QuantumRange*node_info->total_red/number_unique+0.5);
       image->colormap[image->colors].green=(Quantum)
-        (MaxRGB*node_info->total_green/number_unique+0.5);
+        (QuantumRange*node_info->total_green/number_unique+0.5);
       image->colormap[image->colors].blue=(Quantum)
-        (MaxRGB*node_info->total_blue/number_unique+0.5);
+        (QuantumRange*node_info->total_blue/number_unique+0.5);
       node_info->color_number=image->colors++;
     }
 }
@@ -1074,6 +1081,8 @@ MagickExport QuantizeInfo *DestroyQuantizeInfo(QuantizeInfo *quantize_info)
 static MagickBooleanType Dither(CubeInfo *cube_info,Image *image,
   const unsigned int direction)
 {
+#define DitherImageTag  "Dither/Image"
+
   MagickPixelPacket
     error;
 
@@ -1145,8 +1154,8 @@ static MagickBooleanType Dither(CubeInfo *cube_info,Image *image,
           p->color.red=(double) pixel.red;
           p->color.green=(double) pixel.green;
           p->color.blue=(double) pixel.blue;
-          p->distance=3.0*((MagickRealType) MaxRGB+1.0)*
-            ((MagickRealType) MaxRGB+1.0);
+          p->distance=3.0*((MagickRealType) QuantumRange+1.0)*
+            ((MagickRealType) QuantumRange+1.0);
           ClosestColor(image,p,node_info->parent);
           p->cache[i]=(long) p->color_number;
         }
@@ -1172,6 +1181,18 @@ static MagickBooleanType Dither(CubeInfo *cube_info,Image *image,
       p->error[i].red=pixel.red-(double) image->colormap[index].red;
       p->error[i].green=pixel.green-(double) image->colormap[index].green;
       p->error[i].blue=pixel.blue-(double) image->colormap[index].blue;
+      if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+          (QuantumTick(p->offset,p->span) != MagickFalse))
+        {
+          MagickBooleanType
+            status;
+
+          status=image->progress_monitor(DitherImageTag,p->offset,p->span,
+            image->client_data);
+          if (status == MagickFalse)
+            return(MagickFalse);
+        }
+      p->offset++;
     }
   switch (direction)
   {
@@ -1240,6 +1261,8 @@ static MagickBooleanType DitherImage(CubeInfo *cube_info,Image *image)
   i=image->columns > image->rows ? image->columns : image->rows;
   for (depth=1; i != 0; depth++)
     i>>=1;
+  cube_info->offset=0;
+  cube_info->span=(MagickSizeType) image->columns*image->rows;
   HilbertCurve(cube_info,image,depth-1,NorthGravity);
   (void) Dither(cube_info,image,ForgetGravity);
   return(MagickTrue);
@@ -1334,7 +1357,7 @@ static CubeInfo *GetCubeInfo(const QuantizeInfo *quantize_info,
   for (i=0; i < ExceptionQueueLength; i++)
   {
     cube_info->weights[ExceptionQueueLength-i-1]=1.0/weight;
-    weight*=exp(log(((double) MaxRGB+1.0))/(ExceptionQueueLength-1.0));
+    weight*=exp(log(((double) QuantumRange+1.0))/(ExceptionQueueLength-1.0));
   }
   /*
     Normalize the weighting factors.
@@ -1483,7 +1506,7 @@ MagickExport MagickBooleanType GetImageQuantizeError(Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   image->total_colors=GetNumberColors(image,(FILE *) NULL,&image->exception);
   (void) ResetMagickMemory(&image->error,0,sizeof(image->error));
   if (image->storage_class == DirectClass)
@@ -1519,8 +1542,8 @@ MagickExport MagickBooleanType GetImageQuantizeError(Image *image)
     }
   }
   image->error.mean_error_per_pixel=(double) (mean_error_per_pixel/area);
-  image->error.normalized_mean_error=(double) (mean_error/area/MaxRGB/MaxRGB);
-  image->error.normalized_maximum_error=(double) (maximum_error/MaxRGB);
+  image->error.normalized_mean_error=(double) (mean_error/area/QuantumRange/QuantumRange);
+  image->error.normalized_maximum_error=(double) (maximum_error/QuantumRange);
   return(MagickTrue);
 }
 
@@ -1731,7 +1754,7 @@ MagickExport MagickBooleanType MapImage(Image *image,const Image *map_image,
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(map_image != (Image *) NULL);
   assert(map_image->signature == MagickSignature);
   GetQuantizeInfo(&quantize_info);
@@ -1806,7 +1829,7 @@ MagickExport MagickBooleanType MapImages(Image *images,const Image *map_image,
   assert(images != (Image *) NULL);
   assert(images->signature == MagickSignature);
   if (images->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),images->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",images->filename);
   GetQuantizeInfo(&quantize_info);
   quantize_info.dither=dither;
   image=images;
@@ -1815,7 +1838,7 @@ MagickExport MagickBooleanType MapImages(Image *images,const Image *map_image,
       /*
         Create a global colormap for an image sequence.
       */
-      for ( ; image != (Image *) NULL; image=image->next)
+      for ( ; image != (Image *) NULL; image=GetNextImageInList(image))
         if (image->matte != MagickFalse)
           quantize_info.colorspace=TransparentColorspace;
       status=QuantizeImages(&quantize_info,images);
@@ -1837,7 +1860,8 @@ MagickExport MagickBooleanType MapImages(Image *images,const Image *map_image,
         Classify image colors from the reference image.
       */
       quantize_info.number_colors=cube_info->colors;
-      for (image=images; image != (Image *) NULL; image=image->next)
+      image=images;
+      for ( ; image != (Image *) NULL; image=GetNextImageInList(image))
       {
         quantize_info.colorspace=image->matte != MagickFalse ?
           TransparentColorspace : RGBColorspace;
@@ -1877,8 +1901,6 @@ MagickExport MagickBooleanType MapImages(Image *images,const Image *map_image,
 */
 MagickExport MagickBooleanType OrderedDitherImage(Image *image)
 {
-#define DitherImageTag  "Dither/Image"
-
   static Quantum
     DitherMatrix[8][8] =
     {
@@ -2011,7 +2033,7 @@ MagickExport MagickBooleanType PosterizeImage(Image *image,
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   posterize_image=AllocateImage((ImageInfo *) NULL);
   if (posterize_image == (Image *) NULL)
     return(MagickFalse);
@@ -2036,9 +2058,9 @@ MagickExport MagickBooleanType PosterizeImage(Image *image,
     for (j=0; j < l; j++)
       for (k=0; k < l; k++)
       {
-        posterize_image->colormap[n].red=(Quantum) (MaxRGB*i/(l-1));
-        posterize_image->colormap[n].green=(Quantum) (MaxRGB*j/(l-1));
-        posterize_image->colormap[n].blue=(Quantum) (MaxRGB*k/(l-1));
+        posterize_image->colormap[n].red=(Quantum) (QuantumRange*i/(l-1));
+        posterize_image->colormap[n].green=(Quantum) (QuantumRange*j/(l-1));
+        posterize_image->colormap[n].blue=(Quantum) (QuantumRange*k/(l-1));
         *q++=posterize_image->colormap[n];
         indexes[n]=(IndexPacket) n;
         n++;
@@ -2234,7 +2256,7 @@ MagickExport MagickBooleanType QuantizeImage(const QuantizeInfo *quantize_info,
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   number_colors=quantize_info->number_colors;
   if (number_colors == 0)
     number_colors=MaxColormapSize;
@@ -2343,8 +2365,8 @@ MagickExport MagickBooleanType QuantizeImages(const QuantizeInfo *quantize_info,
   assert(images != (Image *) NULL);
   assert(images->signature == MagickSignature);
   if (images->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),images->filename);
-  if (images->next == (Image *) NULL)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",images->filename);
+  if (GetNextImageInList(images) == (Image *) NULL)
     {
       /*
         Handle a single image with QuantizeImage.
@@ -2377,7 +2399,8 @@ MagickExport MagickBooleanType QuantizeImages(const QuantizeInfo *quantize_info,
       if (quantize_info->dither != MagickFalse)
         depth--;
       pseudo_class=MagickTrue;
-      for (image=images; image != (Image *) NULL; image=image->next)
+      image=images;
+      for ( ; image != (Image *) NULL; image=GetNextImageInList(image))
         if (image->storage_class != PseudoClass)
           pseudo_class=MagickFalse;
       if (pseudo_class != MagickFalse)
@@ -2569,7 +2592,7 @@ static void Reduce(CubeInfo *cube_info,const NodeInfo *node_info)
 static void ReduceImageColors(CubeInfo *cube_info,const Image *image,
   const unsigned long number_colors,ExceptionInfo *exception)
 {
-#define ReduceImageTag  " Reduce/Image"
+#define ReduceImageTag  "Reduce/Image"
 
   MagickBooleanType
     status;
