@@ -142,7 +142,7 @@ MagickExport MagickBooleanType AcquireMagickResource(const ResourceType type,
 
   status=MagickFalse;
   FormatSize(size,resource_request);
-  resource_semaphore=AcquireSemaphoreInfo(resource_semaphore);
+  AcquireSemaphoreInfo(&resource_semaphore);
   switch (type)
   {
     case AreaResource:
@@ -405,7 +405,7 @@ MagickExport int AcquireUniqueFileResource(char *path)
 */
 MagickExport void DestroyMagickResources(void)
 {
-  resource_semaphore=AcquireSemaphoreInfo(resource_semaphore);
+  AcquireSemaphoreInfo(&resource_semaphore);
   if (temporary_resources != (SplayTreeInfo *) NULL)
     {
       const char
@@ -456,7 +456,7 @@ MagickExport unsigned long GetMagickResource(const ResourceType type)
     resource;
 
   resource=0;
-  resource_semaphore=AcquireSemaphoreInfo(resource_semaphore);
+  AcquireSemaphoreInfo(&resource_semaphore);
   switch (type)
   {
     case AreaResource:
@@ -611,7 +611,7 @@ MagickExport MagickBooleanType ListMagickResourceInfo(FILE *file,
 
   if (file == (const FILE *) NULL)
     file=stdout;
-  resource_semaphore=AcquireSemaphoreInfo(resource_semaphore);
+  AcquireSemaphoreInfo(&resource_semaphore);
   FormatSize(MegabytesToBytes(resource_info.area_limit),area_limit);
   FormatSize(GigabytesToBytes(resource_info.disk_limit),disk_limit);
   FormatSize((MagickSizeType) resource_info.file_limit,file_limit);
@@ -662,7 +662,7 @@ MagickExport void RelinquishMagickResource(const ResourceType type,
     resource_type[MaxTextExtent];
 
   FormatSize(size,resource_request);
-  resource_semaphore=AcquireSemaphoreInfo(resource_semaphore);
+  AcquireSemaphoreInfo(&resource_semaphore);
   switch (type)
   {
     case AreaResource:
@@ -798,7 +798,7 @@ MagickExport MagickBooleanType RelinquishUniqueFileResource(const char *path)
 MagickExport MagickBooleanType SetMagickResourceLimit(const ResourceType type,
   const unsigned long limit)
 {
-  resource_semaphore=AcquireSemaphoreInfo(resource_semaphore);
+  AcquireSemaphoreInfo(&resource_semaphore);
   switch (type)
   {
     case AreaResource:
