@@ -5,7 +5,7 @@
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
   
-    http://www.imagemagick.org/www/Copyright.html
+    http://www.imagemagick.org/script/license.php
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -22,6 +22,7 @@
 extern "C" {
 #endif
 
+#include <stdarg.h>
 #include "magick/exception.h"
 
 typedef struct _StringInfo
@@ -42,6 +43,7 @@ typedef struct _StringInfo
 extern MagickExport char
   *AcquireString(const char *),
   *CloneString(char **,const char *),
+  *ConstantString(char *),
   *DestroyString(char *),
   **DestroyStringList(char **),
   *EscapeString(const char *,const char),
@@ -53,17 +55,21 @@ extern MagickExport char
 extern MagickExport double
   StringToDouble(const char *,const double);
 
-extern MagickExport int
+extern MagickExport long
   FormatMagickString(char *,const size_t,const char *,...)
     magick_attribute((format (printf,3,4))),
+  FormatMagickStringList(char *,const size_t,const char *,va_list)
+    magick_attribute((format (printf,3,0))),
   LocaleCompare(const char *,const char *),
   LocaleNCompare(const char *,const char *,const size_t);
 
 extern MagickExport MagickBooleanType
-  CompareStringInfo(const StringInfo *,const StringInfo *),
   ConcatenateString(char **,const char *),
   SubstituteString(char **,const char *,const char *);
 
+extern MagickExport int
+  CompareStringInfo(const StringInfo *,const StringInfo *);
+
 extern MagickExport size_t
   ConcatenateMagickString(char *,const char *,const size_t),
   CopyMagickString(char *,const char *,const size_t);
@@ -80,7 +86,7 @@ extern MagickExport void
   ConcatenateStringInfo(StringInfo *,const StringInfo *),
   LocaleLower(char *),
   LocaleUpper(char *),
-  PrintStringInfo(const char *,const StringInfo *),
+  PrintStringInfo(FILE *file,const char *,const StringInfo *),
   ResetStringInfo(StringInfo *),
   SetStringInfoDatum(StringInfo *,const unsigned char *),
   SetStringInfo(StringInfo *,const StringInfo *),
