@@ -244,6 +244,9 @@ WandExport PixelIterator *NewPixelIterator(MagickWand *wand)
   unsigned long
     depth;
 
+  ViewInfo
+    *view;
+
   depth=QuantumDepth;
   quantum=GetMagickQuantumDepth(&depth);
   if (depth != QuantumDepth)
@@ -252,6 +255,9 @@ WandExport PixelIterator *NewPixelIterator(MagickWand *wand)
   image=GetImageFromMagickWand(wand);
   if (image == (Image *) NULL)
     return((PixelIterator *) NULL);
+  view=OpenCacheView(image);
+  if (view == (ViewInfo *) NULL)
+    return((PixelIterator *) NULL);
   iterator=(PixelIterator *) AcquireMagickMemory(sizeof(*iterator));
   if (iterator == (PixelIterator *) NULL)
     ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
@@ -261,7 +267,7 @@ WandExport PixelIterator *NewPixelIterator(MagickWand *wand)
   (void) FormatMagickString(iterator->name,MaxTextExtent,"%s-%lu",
     PixelIteratorId,iterator->id);
   GetExceptionInfo(&iterator->exception);
-  iterator->view=OpenCacheView(image);
+  iterator->view=view;
   SetGeometry(image,&iterator->region);
   iterator->pixel_wand=NewPixelWands(iterator->region.width);
   iterator->y=(-1);
@@ -347,6 +353,9 @@ WandExport PixelIterator *NewPixelRegionIterator(MagickWand *wand,const long x,
   unsigned long
     depth;
 
+  ViewInfo
+    *view;
+
   assert(wand != (MagickWand *) NULL);
   depth=QuantumDepth;
   quantum=GetMagickQuantumDepth(&depth);
@@ -357,6 +366,9 @@ WandExport PixelIterator *NewPixelRegionIterator(MagickWand *wand,const long x,
   image=GetImageFromMagickWand(wand);
   if (image == (Image *) NULL)
     return((PixelIterator *) NULL);
+  view=OpenCacheView(image);
+  if (view == (ViewInfo *) NULL)
+    return((PixelIterator *) NULL);
   iterator=(PixelIterator *) AcquireMagickMemory(sizeof(*iterator));
   if (iterator == (PixelIterator *) NULL)
     ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
@@ -366,7 +378,7 @@ WandExport PixelIterator *NewPixelRegionIterator(MagickWand *wand,const long x,
   (void) FormatMagickString(iterator->name,MaxTextExtent,"%s-%lu",
     PixelIteratorId,iterator->id);
   GetExceptionInfo(&iterator->exception);
-  iterator->view=OpenCacheView(image);
+  iterator->view=view;
   SetGeometry(image,&iterator->region);
   iterator->region.x=x;
   iterator->region.y=y;
