@@ -80,7 +80,7 @@ WandExport unsigned long AcquireWandId(void)
 
   if (wand_ids == (SplayTreeInfo *) NULL)
     {
-      wand_semaphore=AcquireSemaphoreInfo(wand_semaphore);
+      AcquireSemaphoreInfo(&wand_semaphore);
       if (wand_ids == (SplayTreeInfo *) NULL)
         wand_ids=NewSplayTree((int (*)(const void *,const void *)) NULL,
           (void *(*)(void *)) NULL,(void *(*)(void *)) NULL);
@@ -90,7 +90,7 @@ WandExport unsigned long AcquireWandId(void)
   if ((instantiate_magick == MagickFalse) &&
       (GetNumberOfNodesInSplayTree(wand_ids) == 0))
     InitializeMagick((char *) NULL);
-  wand_semaphore=AcquireSemaphoreInfo(wand_semaphore);
+  AcquireSemaphoreInfo(&wand_semaphore);
   id++;
   RelinquishSemaphoreInfo(wand_semaphore);
   (void) AddValueToSplayTree(wand_ids,(const void *) id,(const void *) id);
@@ -129,7 +129,7 @@ WandExport void RelinquishWandId(const unsigned long id)
   if ((instantiate_magick != MagickFalse) ||
       (GetNumberOfNodesInSplayTree(wand_ids) != 0))
     return;
-  wand_semaphore=AcquireSemaphoreInfo(wand_semaphore);
+  AcquireSemaphoreInfo(&wand_semaphore);
   DestroyMagick();
   wand_ids=DestroySplayTree(wand_ids);
   instantiate_magick=MagickFalse;
